#
# spec file for package opensm
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           opensm
Summary:        Infiniband Subnet Manager
License:        BSD-2-Clause or GPL-2.0
Group:          Productivity/Networking/System
Version:        3.3.19
Release:        4.6
Source0:        https://www.openfabrics.org/downloads/management/%{name}-%{version}.tar.gz
Source1:        conf.sysconfig
Source2:        %{name}.launch
Source3:        opensm.service
Source4:        baselibs.conf
Patch0:         opensm-autotools.patch
Patch1:         opensm-type_punning.patch
Url:            http://www.openfabrics.org
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libibumad-devel
BuildRequires:  libibverbs-devel
BuildRequires:  libtool
BuildRequires:  systemd-rpm-macros
PreReq:         %fillup_prereq
Requires:       logrotate
%{?systemd_requires}

%define so_major 3
%define opensm_libname libs%{so_major}

%description
OpenSM provides an implementation for an InfiniBand Subnet Manager and
Administration. Such a software entity is required to run for in order
to initialize the InfiniBand hardware (at least one per each InfiniBand
subnet).

%package        %{opensm_libname}
Summary:        Opensm runtime libraries
Group:          System/Libraries

%description  %{opensm_libname}
This package contains the opensm runtime libraries.

%package        devel
Summary:        Development files for OpenSM
Group:          Development/Libraries/C and C++
Requires:       %{name}-%{opensm_libname} = %{version}
Requires:       libibumad-devel

%description devel
Symlinks for the dynamic libraries and header files for OpenSM.

%prep
%setup -q
%patch0
%patch1

cp %{S:1} %{S:2} %{S:3} .
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" opensm/osm_console.c

%build
autoreconf -fi
%configure --disable-static
make %{?_smp_mflags} V=1

%install
export NO_BRP_STALE_LINK_ERROR=yes
make DESTDIR=%{buildroot} install
install -D -m 644 scripts/opensm.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/opensm

# get rid of the included init script because we use a systemd unit file instead
rm -rf %{buildroot}%_sysconfdir/init.d/
install -Dm 644 %{SOURCE3} %{buildroot}%_unitdir/%{name}.service
install -D %{SOURCE2}  %{buildroot}%{_libexecdir}/opensm-launch
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}d

# install the sysconfig configuration file
install -m 644 -D conf.sysconfig %{buildroot}/var/adm/fillup-templates/sysconfig.%name

# and make a compat link
ln -s %_sysconfdir/sysconfig/opensm %{buildroot}/%_sysconfdir/opensm.conf
sed -i -e 's$-L/usr/src/packages/BUILD/%{name}-%{version}/complib$$g' %{buildroot}%{_libdir}/libosmvendor.la

#we don't package static libraries anymore.
rm -f %{buildroot}%_libdir/lib{opensm,osmcomp,osmvendor}.la

%pre
%service_add_pre opensm.service

%post
%{fillup_only}
%service_add_post opensm.service

%post %{opensm_libname} -p /sbin/ldconfig

%preun
%service_del_preun opensm.service

%postun
%service_del_postun opensm.service

%postun %{opensm_libname} -p /sbin/ldconfig

%files
%defattr(-, root, root)
%_sysconfdir/opensm.conf
%doc COPYING
%_unitdir/opensm.service
%config %_sysconfdir/logrotate.d/opensm
%_sbindir/*
%{_libexecdir}/opensm-launch
%_mandir/man5/torus-2QoS.conf.5.gz
%_mandir/man8/torus-2QoS.8.gz
%_mandir/man8/opensm.8.gz
%_mandir/man8/osmtest.8.gz
/var/adm/fillup-templates/sysconfig.%name

%files %{opensm_libname}
%defattr(-, root, root)
%_libdir/libopensm.so.*
%_libdir/libosmcomp.so.*
%_libdir/libosmvendor.so.*

%files devel
%defattr(-,root,root)
%_includedir/infiniband/complib/
%_includedir/infiniband/iba/
%_includedir/infiniband/opensm/
%_includedir/infiniband/vendor/
%_libdir/libopensm.so
%_libdir/libosmcomp.so
%_libdir/libosmvendor.so

%changelog
* Sun Mar  8 2015 p.drouand@gmail.com
- Update to version 3.3.19
  * No concise list of changes present so see the file ChangeLog in
    the package documentation directory.
- Move to systemd
  * Replace opensmd with opensm.service
  * Replace sldd.sh with opensm.launch
  * Add systemd-rpm-macros and %%{?systemd_requires} require
  * Replace sysvinit post/postun macros with systemd one
- Use download Url as source
- Get rid of some extra stuff
* Tue Aug 26 2014 fcrozat@suse.com
- Add obsoletes/provides to baselibs.conf.
* Tue Aug 12 2014 pth@suse.de
- Fix the Processname stated in a comment (bnc#884648).
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Tue Apr 22 2014 pth@suse.de
- Build for s390.
* Thu Feb 13 2014 pth@suse.de
- Update to 3.3.17 for fate#315488. No concise list of changes
  present so see the file ChangeLog in the package documentation
  directory.
* Mon Feb 10 2014 pth@suse.de
- Fix license, include COPYING.
- Fix baselibs.conf.
* Fri Jan 31 2014 pth@suse.de
- Only ppc64le is supported so remove everything that triggered
  on ppc or ppc64.
- Remove opensm-no_g0_when_daemon.patch as the fix has been
  integrated.
* Fri Jan 24 2014 pth@suse.de
- Remove old tarball.
* Mon Jan 20 2014 pth@suse.de
- Update to 3.3.16 from OFED 3.12.
- Use spdx.org format for license specification.
- fix type-punning by using unions: opensm-type_punning.patch.
* Wed Jan 15 2014 pth@suse.de
- Use spdx.org for license specification.
* Thu Sep 13 2012 pth@suse.de
- Use sed instead of a patch to fix the use of __DATE__ and __TIME__.
* Tue Sep 11 2012 pth@suse.de
- Update to 3.3.13 from OFED 1.5.4.1
* Tue Jul  3 2012 pth@suse.de
- Update to 3.3.12 from OFED 1.5.4.
- Split off shared libraries to their own package.
- Don't use __DATE_ and __TIME__ in version output.
- Provide /usr/sbin/rcopensmd symlink.
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Tue Dec 14 2010 pth@suse.de
- Fix name of libibumad devel package.
* Mon Dec 13 2010 pth@suse.de
- Split off static libraries to their own sub package.
* Wed Oct 27 2010 jjolly@novell.com
- one more dependency version for libibumad
* Wed Oct 27 2010 jjolly@novell.com
- Versioned the libibumad dependency
* Mon Oct 25 2010 jjolly@novell.com
- Update to v3.3.7 from OFED 1.5.2
- Removed Weighted Routing Patch
* Thu Dec  3 2009 jjolly@suse.de
- Corrected path in opensmd to opensm (bnc#529746)
* Thu Dec  3 2009 jjolly@suse.de
- Weighted routing patch (bnc#540371,FATE#306944)
* Thu Dec  3 2009 jjolly@suse.de
- Updated to 3.2.6_20090317 from OFED 1.4.2
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Nov 20 2008 jjolly@suse.de
- Updated to 3.2.3_20081117_b70e2d2 from OFED 1.4 rc5
  - adapted header files for OFED 1.4
* Thu Nov  6 2008 ihno@suse.de
- Adding baselibs.conf
- Adding ExcludeArch s390 s390x
* Fri Oct 24 2008 jjolly@suse.de
- Updated to version from the OFED 1.4 RC3
* Thu Sep 11 2008 jjolly@suse.de
- Update to 3.2.2 from the OFED 1.4 RC1
* Tue Mar  4 2008 jjolly@suse.de
- Update to 3.1.10 from the OFED 1.3 GA release
- Added bison and flex to the BuildRequires list
* Wed Feb 13 2008 pth@suse.de
- Remove references to $srcdir from RPATH.
- Add Short-Description to opensm init script
- Add AM_PROG_CC_C_O to configure
- Run autoreconf
- Pass [foreign] to AM_INIT_AUTOMAKE
- Update to 3.1.8:
  Number of changes far too long, see NEWS for a detailed list
* Tue Oct  2 2007 dbahi@suse.de
- Added %%preun to stop opensmd
* Mon Aug 20 2007 hvogel@suse.de
- Update to version from OFED 1.2.5
- readd the init scripts from OFED instead of the default opensm
  one
* Tue Aug  7 2007 hvogel@suse.de
- Update to version from OFED 1.2c
* Thu Jul 12 2007 hvogel@suse.de
- Install a missing script
- Install configuration as sysconfig file
- Include init script
* Wed Jul  4 2007 hvogel@suse.de
- Add GPL COPYING file [#289225]
* Tue Jul  3 2007 hvogel@suse.de
- Use 3.0.3 which is the correct version included in
  OFED 1.2
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 2.2.0
